@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0013';
+our $VERSION = '0.0014';
 
 use Moo;
 use strictures 2;
@@ -103,9 +103,10 @@ sub recall_settings {
   my ($self, %args) = @_;
   my $name = delete $args{name};
   croak 'No name given' unless $name;
-  my $results = $self->_sqlite->query(
-    'select id,settings from ' . $self->model . " where name='$name'"
-  );
+  my $sql = q/select id,settings,json_extract(settings, '$.group') as mygroup from /
+    . $self->model
+    . " where name='$name' order by mygroup";
+  my $results = $self->_sqlite->query($sql);
   my @settings;
   while (my $next = $results->hash) {
     push @settings, { $next->{id} => from_json($next->{settings}) };
@@ -114,6 +115,22 @@ sub recall_settings {
 }
 
 
+sub recall_all {
+  my ($self) = @_;
+  my $sql = q/select id,name,settings,json_extract(settings, '$.group') as mygroup from /
+    . $self->model
+    . ' order by name,mygroup';
+  my $results = $self->_sqlite->query($sql);
+  my @settings;
+  while (my $next = $results->hash) {
+    push @settings, { $next->{id} => from_json($next->{settings}) };
+    # add the setting name to the settings data
+    $settings[-1]->{ $next->{id} }{name} = $next->{name};
+  }
+  return \@settings;
+}
+
+
 sub search_settings {
   my ($self, %args) = @_;
   my @where;
@@ -122,7 +139,10 @@ sub search_settings {
     push @where, q/json_extract(settings, '$./ . $arg . q/') = / . "'$args{$arg}'";
   }
   return [] unless @where;
-  my $sql = 'select id,settings from ' . $self->model . ' where ' . join(' and ', @where);
+  my $sql = q/select id,settings,json_extract(settings, '$.group') as mygroup from /
+    . $self->model
+    . ' where ' . join(' and ', @where)
+    . ' order by mygroup';
   my $results = $self->_sqlite->query($sql);
   my @settings;
   while (my $next = $results->hash) {
@@ -176,7 +196,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0013
+version 0.0014
 
 =head1 SYNOPSIS
 
@@ -283,6 +303,12 @@ Return the parameters of a setting for the given B<id>.
 
 Return all the settings for a given B<name>.
 
+=head2 recall_all
+
+  my $settings = $synth->recall_all;
+
+Return all the settings for the synth model.
+
 =head2 search_settings
 
   my $settings = $synth->search_settings(some_setting => $value);
